summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/net/tls.c9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/net/tls.c b/src/net/tls.c
index d28daa43..9d994cd7 100644
--- a/src/net/tls.c
+++ b/src/net/tls.c
@@ -2747,9 +2747,14 @@ static void tls_tx_step ( struct tls_connection *tls ) {
tls->tx_pending &= ~TLS_TX_FINISHED;
}
- /* Reschedule process if pending transmissions remain */
- if ( tls->tx_pending )
+ /* Reschedule process if pending transmissions remain,
+ * otherwise send notification of a window change.
+ */
+ if ( tls->tx_pending ) {
tls_tx_resume ( tls );
+ } else {
+ xfer_window_changed ( &tls->plainstream );
+ }
return;